@@ -336,10 +336,12 @@ typedef enum
 
 /**
  * GgitConfigLevel:
+ * @GGIT_CONFIG_LEVEL_PROGRAMDATA: System-wide on Windows, for compatibility with portable git.
  * @GGIT_CONFIG_LEVEL_SYSTEM: System-wide configuration file.
  * @GGIT_CONFIG_LEVEL_XDG: XDG compatible configuration file (.config/git/config).
  * @GGIT_CONFIG_LEVEL_GLOBAL: User-specific configuration file, also called Global configuration file.
  * @GGIT_CONFIG_LEVEL_LOCAL: Repository specific configuration file.
+ * @GGIT_CONFIG_LEVEL_APP: Application specific configuration file; freely defined by applications.
  * @GGIT_CONFIG_LEVEL_HIGHEST: Represents the highest level of a config file.
  *
  * Priority level of a config file.
@@ -348,11 +350,14 @@ typedef enum
  */
 typedef enum
 {
-	GGIT_CONFIG_LEVEL_SYSTEM  = 1,
-	GGIT_CONFIG_LEVEL_XDG     = 2,
-	GGIT_CONFIG_LEVEL_GLOBAL  = 3,
-	GGIT_CONFIG_LEVEL_LOCAL   = 4,
-	GGIT_CONFIG_LEVEL_HIGHEST = -1
+	GGIT_CONFIG_LEVEL_PROGRAMDATA = 1,
+	GGIT_CONFIG_LEVEL_SYSTEM      = 2,
+	GGIT_CONFIG_LEVEL_XDG         = 3,
+	GGIT_CONFIG_LEVEL_GLOBAL      = 4,
+	GGIT_CONFIG_LEVEL_LOCAL       = 5,
+	GGIT_CONFIG_LEVEL_WORKTREE    = 6,
+	GGIT_CONFIG_LEVEL_APP         = 7,
+	GGIT_CONFIG_LEVEL_HIGHEST     = -1
 } GgitConfigLevel;
 
 /**
@@ -389,7 +394,11 @@ typedef enum {
 	GGIT_DELTA_RENAMED    = 4,
 	GGIT_DELTA_COPIED     = 5,
 	GGIT_DELTA_IGNORED    = 6,
-	GGIT_DELTA_UNTRACKED  = 7
+	GGIT_DELTA_UNTRACKED  = 7,
+	GGIT_DELTA_TYPECHANGE = 8,
+	GGIT_DELTA_UNREADABLE = 9,
+	GGIT_DELTA_CONFLICTED = 10,
+
 } GgitDeltaType;
 
 /**
@@ -600,12 +609,39 @@ typedef enum {
 } GgitMergeFileFlags;
 
 /**
- * GgitMergeTreeFlags:
- * @GGIT_MERGE_TREE_FIND_RENAMES: detect renames.
+ * GgitMergeFlags:
+ * @GGIT_MERGE_FIND_RENAMES: detect renames that occur between the common
+ * ancestor and the "ours" side or the common ancestor and the "theirs" side.
+ * This will enable the ability to merge between a modified and renamed file.
+ * @GGIT_MERGE_FAIL_ON_CONFLICT: If a conflict occurs, exit immediately instead
+ * of attempting to continue resolving conflicts.  The merge operation will
+ * fail with @GGIT_EMERGECONFLICT and no index will be returned.
+ * @GGIT_MERGE_SKIP_REUC: do not write the REUC extension on the generated index.
+ * @GGIT_MERGE_NO_RECURSIVE: If the commits being merged have multiple merge bases,
+ * do not build a recursive merge base (by merging the multiple merge bases),
+ * instead simply use the first base.  This flag provides a similar
+ * merge base to `git-merge-resolve`.
  */
 typedef enum {
-	GGIT_MERGE_TREE_FIND_RENAMES = (1 << 0)
-} GgitMergeTreeFlags;
+	GGIT_MERGE_FIND_RENAMES     = (1 << 0),
+	GGIT_MERGE_FAIL_ON_CONFLICT = (1 << 1),
+	GGIT_MERGE_SKIP_REUC        = (1 << 2),
+	GGIT_MERGE_NO_RECURSIVE     = (1 << 3)
+} GgitMergeFlags;
+
+/**
+ * GgitProxyType:
+ * @GGIT_PROXY_NONE: Do not attempt to connect through a proxy.
+ * @GGIT_PROXY_AUTO: Try to auto-detect the proxy from the git configuration.
+ * @GGIT_PROXY_SPECIFIED: Connect via the URL given in the options.
+ *
+ * The type of proxy to use.
+ */
+typedef enum {
+	GGIT_PROXY_NONE,
+	GGIT_PROXY_AUTO,
+	GGIT_PROXY_SPECIFIED
+} GgitProxyType;
 
 /**
  * GgitRebaseOperationType:
@@ -769,7 +805,10 @@ typedef enum {
 	GGIT_STATUS_WORKING_TREE_MODIFIED   = 1 << 8,
 	GGIT_STATUS_WORKING_TREE_DELETED    = 1 << 9,
 	GGIT_STATUS_WORKING_TREE_TYPECHANGE = 1 << 10,
-	GGIT_STATUS_IGNORED                 = 1 << 14
+	GGIT_STATUS_WORKING_TREE_RENAMED    = 1 << 11,
+	GGIT_STATUS_WORKING_TREE_UNREADABLE = 1 << 12,
+	GGIT_STATUS_IGNORED                 = 1 << 14,
+	GGIT_STATUS_CONFLICTED              = 1 << 15,
 } GgitStatusFlags;
 
 /**
@@ -951,8 +990,8 @@ typedef enum
 
 typedef enum
 {
-	GGIT_CHECKOUT_NONE                    = 0,
-	GGIT_CHECKOUT_SAFE                    = (1u << 0),
+	GGIT_CHECKOUT_NONE                    = (1u << 30),
+	GGIT_CHECKOUT_SAFE                    = 0,
 	GGIT_CHECKOUT_FORCE                   = (1u << 1),
 	GGIT_CHECKOUT_RECREATE_MISSING        = (1u << 2),
 	GGIT_CHECKOUT_ALLOW_CONFLICTS         = (1u << 4),
@@ -1109,7 +1148,7 @@ typedef gint (* GgitDiffHunkCallback) (GgitDiffDelta *delta,
 /**
  * GgitDiffLineCallback:
  * @delta: a #GgitDiffDelta.
- * @hunk: a #GgitDiffHunk.
+ * @hunk: (nullable): a #GgitDiffHunk.
  * @line: a #GgitDiffLine.
  * @user_data: (closure): user-supplied data.
  *
